@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Installer for libarchive
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
 
 sub versions_available
@@ -128,7 +128,7 @@ sub system_install
     };
     return $build unless $@;
   }
-  
+
   my $build = bless {
     cflags => _try_pkg_config(undef, 'cflags', '', ''),
     libs   => _try_pkg_config(undef, 'libs',   '-larchive', ''),
@@ -141,7 +141,7 @@ sub system_install
     if($^O eq 'MSWin32')
     {
       # On MSWin32 the entire path is not included in dl_library_path
-      # buth that is the most likely place that we will find dlls.
+      # but that is the most likely place that we will find dlls.
       @dir_search_list = grep { -d $_ } split /;/, $ENV{PATH};
     }
     else
@@ -183,7 +183,7 @@ sub system_install
       closedir $dh;
     }
   }
-  
+
   $build->test_compile_run || die $build->error if $options{test} =~ /^(compile|both)$/;
   $build->test_ffi || die $build->error if $options{test} =~ /^(ffi|both)$/;
   $build;
@@ -416,6 +416,7 @@ sub dlls
   my($self, $prefix) = @_;
   
   $prefix = $self->{prefix} unless defined $prefix;
+  $prefix = '' if $^O eq 'MSWin32' && $prefix eq '\\';
   
   unless(defined $self->{dlls} && defined $self->{dll_dir})
   {
@@ -462,7 +463,9 @@ sub dlls
   }
   
   require File::Spec;
-  map { File::Spec->catfile($prefix, @{ $self->{dll_dir} }, $_ ) } @{ $self->{dlls} };
+  $^O eq 'MSWin32'
+    ? map { File::Spec->catfile(         @{ $self->{dll_dir} }, $_ ) } @{ $self->{dlls} }
+    : map { File::Spec->catfile($prefix, @{ $self->{dll_dir} }, $_ ) } @{ $self->{dlls} };
 }
 
 
@@ -599,7 +602,7 @@ Alien::Libarchive::Installer - Installer for libarchive
 
 =head1 VERSION
 
-version 0.12
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -947,8 +950,6 @@ or L<test_ffi|Alien::Libarchive::Installer#test_ffi>.
 
 =back
 
-=cut
-
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
